@@ -1,21 +1,15 @@
-#
-# REST.pm
-# Created by: Adam Jacob, Marchex, <adam@hjksolutions.com>
-# Created on: 10/13/2006 03:54:33 PM PDT
-#
-# $Id: $
-
 package Catalyst::Request::REST;
-
-use strict;
-use warnings;
-use Scalar::Util qw/blessed/;
-
-use base qw/Catalyst::Request Class::Accessor::Fast/;
+use Moose;
 
 use Catalyst::Utils;
-use HTTP::Headers::Util qw(split_header_words);
+use namespace::autoclean;
 
+extends 'Catalyst::Request';
+with 'Catalyst::TraitFor::Request::REST';
+
+# Please don't take this as a recommended way to do things.
+# The code below is grotty, badly factored and mostly here for back
+# compat..
 sub _insert_self_into {
   my ($class, $app_class ) = @_;
   # the fallback to $app_class is for the (rare and deprecated) case when
@@ -25,14 +19,25 @@ sub _insert_self_into {
 
   my $req_class = $app->request_class;
   return if $req_class->isa($class);
+  my $req_class_meta = Moose->init_meta( for_class => $req_class );
+  return if $req_class_meta->does_role('Catalyst::TraitFor::Request::REST');
   if ($req_class eq 'Catalyst::Request') {
     $app->request_class($class);
-  } else {
-    die "$app has a custom request class $req_class, "
-      . "which is not a $class; see Catalyst::Request::REST";
+  }
+  else {
+      my $meta = Moose::Meta::Class->create_anon_class(
+          superclasses => [$req_class],
+          roles => ['Catalyst::TraitFor::Request::REST'],
+          cache => 1
+      );
+      $meta->add_method(meta => sub { $meta });
+      $app->request_class($meta->name);
   }
 }
 
+__PACKAGE__->meta->make_immutable;
+__END__
+
 =head1 NAME
 
 Catalyst::Request::REST - A REST-y subclass of Catalyst::Request
@@ -59,14 +64,12 @@ custom request class inherits from C<Catalyst::Request::REST>.
 
 =head1 METHODS
 
+=over
+
+=item data
+
 If the request went through the Deserializer action, this method will
-returned the deserialized data structure.
-
-=cut
-
-__PACKAGE__->mk_accessors(qw(data accept_only));
-
-=over 4
+return the deserialized data structure.
 
 =item accepted_content_types
 
@@ -97,95 +100,26 @@ relative quality specified for each type.
 If a type appears in more than one of these places, it is ordered based on
 where it is first found.
 
-=cut
-
-sub accepted_content_types {
-    my $self = shift;
-
-    return $self->{content_types} if $self->{content_types};
-
-    my %types;
-
-    # First, we use the content type in the HTTP Request.  It wins all.
-    $types{ $self->content_type } = 3
-        if $self->content_type;
-
-    if ($self->method eq "GET" && $self->param('content-type')) {
-        $types{ $self->param('content-type') } = 2;
-    }
-
-    # Third, we parse the Accept header, and see if the client
-    # takes a format we understand.
-    #
-    # This is taken from chansen's Apache2::UploadProgress.
-    if ( $self->header('Accept') ) {
-        $self->accept_only(1) unless keys %types;
-
-        my $accept_header = $self->header('Accept');
-        my $counter       = 0;
-
-        foreach my $pair ( split_header_words($accept_header) ) {
-            my ( $type, $qvalue ) = @{$pair}[ 0, 3 ];
-            next if $types{$type};
-
-            # cope with invalid (missing required q parameter) header like:
-            # application/json; charset="utf-8"
-            # http://tools.ietf.org/html/rfc2616#section-14.1
-            unless ( defined $pair->[2] && lc $pair->[2] eq 'q' ) {
-                $qvalue = undef;
-            }
-
-            unless ( defined $qvalue ) {
-                $qvalue = 1 - ( ++$counter / 1000 );
-            }
-
-            $types{$type} = sprintf( '%.3f', $qvalue );
-        }
-    }
-
-    return $self->{content_types} =
-        [ sort { $types{$b} <=> $types{$a} } keys %types ];
-}
-
 =item preferred_content_type
 
 This returns the first content type found. It is shorthand for:
 
   $request->accepted_content_types->[0]
 
-=cut
-
-sub preferred_content_type { $_[0]->accepted_content_types->[0] }
-
 =item accepts($type)
 
 Given a content type, this returns true if the type is accepted.
 
 Note that this does not do any wildcard expansion of types.
 
-=cut
-
-sub accepts {
-    my $self = shift;
-    my $type = shift;
-
-    return grep { $_ eq $type } @{ $self->accepted_content_types };
-}
-
 =back
 
-=head1 AUTHOR
+=head1 AUTHORS
 
-Adam Jacob <adam@stalecoffee.org>, with lots of help from mst and jrockway
-
-=head1 MAINTAINER
-
-J. Shirley <jshirley@cpan.org>
+See L<Catalyst::Action::REST> for authors.
 
 =head1 LICENSE
 
 You may distribute this code under the same terms as Perl itself.
 
 =cut
-
-1;
